@@ -3,6 +3,6 @@ from __future__ import absolute_import, division, print_function, unicode_litera
 
 ASSET_MANAGER_TYPES = {'Accredited Investor', 'Bank', 'Broker', 'Corporate Treasury', 'Family Office',
                        'Fund Administrator', 'Fund Manager', 'Hedge Fund', 'Individual', 'Private Equity',
-                       'Venture Capital', 'Data Provider'}
-RELATIONSHIP_TYPES = {'Administrator', 'External', 'Front Office', 'Employee', 'Data Provider'}
-ACCOUNT_TYPES = {'Internal', 'Test', 'Basic', 'Professional'}
\ No newline at end of file
+                       'Trust Fund', 'Venture Capital', 'Data Provider'}
+RELATIONSHIP_TYPES = {'Administrator', 'External', 'Front Office', 'Employee', 'Data Provider', 'Demo'}
+ACCOUNT_TYPES = {'Internal', 'Test', 'Basic', 'Professional', 'Demo'}
\ No newline at end of file
