@@ -5,14 +5,13 @@ import json
 import logging
 
 from amaascore.assets.utils import json_to_asset
-from amaascore.config import ENVIRONMENT
 from amaascore.core.interface import Interface
 from amaascore.core.amaas_model import json_handler
 
 
 class AssetsInterface(Interface):
 
-    def __init__(self, environment=ENVIRONMENT, endpoint=None, logger=None, username=None,
+    def __init__(self, environment=None, endpoint=None, logger=None, username=None,
                        password=None, session_token=None):
         self.logger = logger or logging.getLogger(__name__)
         super(AssetsInterface, self).__init__(endpoint=endpoint, endpoint_type='assets', session_token=session_token,
@@ -260,3 +259,30 @@ class AssetsInterface(Interface):
         else:
             self.logger.error(response.text)
             response.raise_for_status()
+
+    def synch(self, asset_manager_id, **params):
+        """
+        This method invokes a request to synch the assets in
+        dynamodb and/or elastic search with the SQL assets.
+
+        Args:
+            asset_manager_id (int): The id of the asset manager that owns the assets to be synched
+            cache (bool): Whether to synch the assets in DynamoDB
+            search (bool): Whether to synch the assets in Elasticsearch
+            page_no (int): The current page of assets to be synched.
+            page_size (int): The number of assets to be synched per request.
+        
+        Returns:
+            int: the number of assets synched.
+        """
+        self.logger.info('Synching Assets.')
+        url = '%s/synch/%s' % (self.endpoint, asset_manager_id)
+        response = self.session.put(url, params=params)
+
+        if response.ok:
+            count = response.json().get('count', 0)
+            self.logger.info('Synched %s Assets.', count)
+            return count
+        else:
+            self.logger.error(response.text)
+            response.raise_for_status()
\ No newline at end of file
