@@ -3,20 +3,19 @@ from __future__ import absolute_import, division, print_function, unicode_litera
 from dateutil.parser import parse
 import logging
 
-from amaascore.config import ENVIRONMENT
 from amaascore.core.interface import Interface
 
 
 class FundamentalsInterface(Interface):
 
-    def __init__(self, environment=ENVIRONMENT, logger=None, endpoint=None, username=None, 
+    def __init__(self, environment=None, logger=None, endpoint=None, username=None, 
                        password=None, session_token=None):
         logger = logger or logging.getLogger(__name__)
         super(FundamentalsInterface, self).__init__(endpoint=endpoint,
                                                     endpoint_type='fundamentals',
                                                     environment=environment,
-                                                    username=None,
-                                                    password=None,
+                                                    username=username,
+                                                    password=password,
                                                     session_token=session_token,
                                                     logger=logger)
 
@@ -77,4 +76,4 @@ class FundamentalsInterface(Interface):
             return response.json()
         else:
             self.logger.error(response.text)
-            response.raise_for_status()
\ No newline at end of file
+            response.raise_for_status()
