@@ -3,7 +3,6 @@ from __future__ import absolute_import, division, print_function, unicode_litera
 import json
 import logging
 
-from amaascore.config import ENVIRONMENT
 from amaascore.core.amaas_model import json_handler
 from amaascore.core.interface import Interface
 from amaascore.market_data.utils import json_to_eod_price, json_to_fx_rate, json_to_curve
@@ -11,7 +10,7 @@ from amaascore.market_data.utils import json_to_eod_price, json_to_fx_rate, json
 
 class MarketDataInterface(Interface):
 
-    def __init__(self, environment=ENVIRONMENT, logger=None, endpoint=None, username=None, 
+    def __init__(self, environment=None, logger=None, endpoint=None, username=None, 
                  password=None, session_token=None):
         self.logger = logger or logging.getLogger(__name__)
         super(MarketDataInterface, self).__init__(endpoint=endpoint, endpoint_type='market_data', session_token=session_token,
@@ -128,9 +127,9 @@ class MarketDataInterface(Interface):
         if business_date_end:
             params['business_date_end'] = business_date_end.date().isoformat()
         if rate_timestamp_start:
-            params['rate_timestamp_start'] = rate_timestamp_start.isoformat()
+            params['rate_timestamp_start'] = rate_timestamp_start.strftime('%H:%m:%s')
         if rate_timestamp_end:
-            params['rate_timestamp_end'] = rate_timestamp_end.isoformat()
+            params['rate_timestamp_end'] = rate_timestamp_end.strftime('%H:%m:%s')
 
         response = self.session.get(url=url, params=params)
         if response.ok:
@@ -218,6 +217,30 @@ class MarketDataInterface(Interface):
         if response.ok:
             self.logger.info('Recieved %s custom market data points', str(len(response.json())))
             return response.json()
+        else:
+            self.logger.error(response.text)
+            response.raise_for_status()
+
+
+    def last_available_business_date(self, asset_manager_id, asset_ids, page_no=None, page_size=None):
+        """
+        Returns the last available business date for the assets so we know the 
+        starting date for new data which needs to be downloaded from data providers.
+        
+        This method can only be invoked by system user
+        """
+        self.logger.info('Retrieving last available business dates for assets')
+        url = '%s/last-available-business-date' % self.endpoint
+        params = {'asset_manager_ids': [asset_manager_id],
+                  'asset_ids': ','.join(asset_ids)}
+        if page_no:
+            params['page_no'] = page_no
+        if page_size:
+            params['page_size'] = page_size
+        response = self.session.get(url, params=params)
+        if response.ok:
+            self.logger.info("Received %s assets' last available business date", len(response.json()))
+            return response.json()
         else:
             self.logger.error(response.text)
             response.raise_for_status()
\ No newline at end of file
