@@ -3,7 +3,6 @@ from __future__ import absolute_import, division, print_function, unicode_litera
 import json
 import logging
 
-from amaascore.config import ENVIRONMENT
 from amaascore.core.amaas_model import json_handler
 from amaascore.core.interface import Interface
 from amaascore.parties.utils import json_to_party
@@ -11,14 +10,14 @@ from amaascore.parties.utils import json_to_party
 
 class PartiesInterface(Interface):
 
-    def __init__(self, environment=ENVIRONMENT, logger=None, endpoint=None, username=None, 
+    def __init__(self, environment=None, logger=None, endpoint=None, username=None, 
                        password=None, session_token=None):
         self.logger = logger or logging.getLogger(__name__)
         super(PartiesInterface, self).__init__(endpoint=endpoint,
                                                endpoint_type='parties',
-                                               environment=environment, 
-                                               username=None,
-                                               password=None,
+                                               environment=environment,
+                                               username=username,
+                                               password=password,
                                                session_token=session_token)
 
     def new(self, party):
@@ -127,3 +126,26 @@ class PartiesInterface(Interface):
         else:
             self.logger.error(response.text)
             response.raise_for_status()
+
+    def synch(self, asset_manager_id):
+        """
+        This method invokes a request to synch the parties in
+        elastic search with the SQL parties.
+
+        Args:
+            asset_manager_id (int): The id of the asset manager that owns the parties to be synched
+        
+        Returns:
+            int: the number of parties synched.
+        """
+        self.logger.info('Synching Parties.')
+        url = '%s/synch/%s' % (self.endpoint, asset_manager_id)
+        response = self.session.put(url)
+
+        if response.ok:
+            count = response.json().get('count', 0)
+            self.logger.info('Synched %s Parties.', count)
+            return count
+        else:
+            self.logger.error(response.text)
+            response.raise_for_status()
\ No newline at end of file
