@@ -15,6 +15,7 @@ from amaascore.transactions.transaction_pnl import TransactionPNL
 from amaascore.transactions.position import Position
 from amaascore.transactions.position_pnl import PositionPNL
 from amaascore.transactions.transaction import Transaction
+from amaascore.transactions.book_report import BookReport
 
 CHARGE_TYPES = ['Tax', 'Commission']
 CODE_TYPES = ['Settle Code', 'Client Classifier']
@@ -44,7 +45,7 @@ def generate_common(asset_manager_id, asset_book_id, counterparty_book_id, asset
 
 def generate_position_pnl(asset_manager_id=None, book_id=None, asset_id=None, period=None, quantity=None,
                         business_date=None, version=None, total_pnl=None, asset_pnl=None, fx_pnl=None,
-                        unrealised_pnl=None, realised_pnl=None, message=None, client_id=None, currency=None,
+                        unrealised_pnl=None, realised_pnl=None, error_message=None, client_id=None, currency=None,
                         pnl_timestamp=None, pnl_status='Active'):
     total_pnl = random.randrange(-100000000, 2000000000)
     asset_pnl = random.randrange(-100000000, 1000000000)
@@ -61,7 +62,7 @@ def generate_position_pnl(asset_manager_id=None, book_id=None, asset_id=None, pe
                            unrealised_pnl=unrealised_pnl,
                            quantity=quantity,
                            realised_pnl=realised_pnl,
-                           message=message or '',
+                           error_message=error_message or '',
                            currency=currency or 'USD',
                            pnl_timestamp=pnl_timestamp or datetime.datetime.utcnow(),
                            client_id=client_id or 1,
@@ -69,8 +70,8 @@ def generate_position_pnl(asset_manager_id=None, book_id=None, asset_id=None, pe
     return position_pnl
 
 def generate_transaction_pnl(asset_manager_id=None, book_id=None, asset_id=None, period=None, quantity=None,
-                        business_date=None, version=None, total_pnl=None, asset_pnl=None, fx_pnl=None,
-                        unrealised_pnl=None, realised_pnl=None, message=None, client_id=None,
+                        business_date=None, version=None, total_pnl=None, asset_pnl=None, fx_pnl=None, additional=None,
+                        unrealised_pnl=None, realised_pnl=None, error_message=None, client_id=None, transaction_date=None,
                         transaction_id=None, pnl_timestamp=None, pnl_status='Active', currency=None):
     total_pnl = random.randrange(-100000000, 2000000000)
     asset_pnl = random.randrange(-100000000, 1000000000)
@@ -79,7 +80,9 @@ def generate_transaction_pnl(asset_manager_id=None, book_id=None, asset_id=None,
                            book_id=book_id or random_string(8),
                            asset_id=asset_id or random_string(10),
                            period=period or random.choice(['YTD', 'MTD', 'DTD']),
+                           transaction_date=transaction_date or datetime.date.today() + datetime.timedelta(days=-7),
                            business_date=business_date or datetime.date.today(),
+                           additional=additional,
                            version=version or 1,
                            total_pnl=total_pnl or str(total_pnl),
                            fx_pnl=fx_pnl or str(fx_pnl),
@@ -87,7 +90,7 @@ def generate_transaction_pnl(asset_manager_id=None, book_id=None, asset_id=None,
                            unrealised_pnl=unrealised_pnl,
                            quantity=quantity,
                            realised_pnl=realised_pnl,
-                           message=message or '',
+                           error_message=error_message or '',
                            currency=currency or 'USD',
                            transaction_id=transaction_id or random_string(16),
                            pnl_timestamp=pnl_timestamp or datetime.datetime.utcnow(),
@@ -95,6 +98,24 @@ def generate_transaction_pnl(asset_manager_id=None, book_id=None, asset_id=None,
                            pnl_status=pnl_status)
     return transaction_pnl
 
+def generate_book_report(asset_manager_id=None, book_id=None, currency=None, report_type=None, business_date=None,
+                         report_timestamp=None, mtm_value=None, total_pnl=None, asset_pnl=None, fx_pnl=None, message='',
+                         report_status=None, period=None):
+    book_report = BookReport(asset_manager_id=asset_manager_id or random.randint(1, 100),
+                             book_id=book_id or random_string(8),
+                             currency=currency or 'USD',
+                             report_type=report_type or 'MTM',
+                             business_date=business_date or datetime.date.today(),
+                             report_timestamp=report_timestamp or datetime.datetime.now(),
+                             mtm_value=mtm_value or random.random() * 100000,
+                             total_pnl=total_pnl,
+                             asset_pnl=asset_pnl,
+                             fx_pnl=fx_pnl,
+                             message=message,
+                             period=period or 'N/A',
+                             report_status=report_status or 'Active')
+    return book_report
+
 def generate_mtm_result(asset_manager_id=None, book_id=None, mtm_value=None, business_date=None, mtm_timestamp=None,
                         asset_id=None, message=None, client_id=None, mtm_status=None):
     mtm_result = MTMResult(asset_manager_id=asset_manager_id or random.randint(1, 10000), 
