@@ -3,20 +3,21 @@ from __future__ import absolute_import, division, print_function, unicode_litera
 import logging
 import json
 
-from amaascore.config import ENVIRONMENT
 from amaascore.core.amaas_model import json_handler
 from amaascore.core.interface import Interface
-from amaascore.transactions.utils import json_to_transaction, json_to_position, \
-    json_to_mtm_result, json_to_transaction_pnl, json_to_position_pnl
+from amaascore.transactions.utils import (
+    json_to_transaction, json_to_position, json_to_mtm_result,
+    json_to_transaction_pnl, json_to_position_pnl, json_to_book_report,
+)
 
 
 class TransactionsInterface(Interface):
 
-    def __init__(self, environment=ENVIRONMENT, logger=None, endpoint=None, username=None, 
+    def __init__(self, environment=None, logger=None, endpoint=None, username=None,
                        password=None, session_token=None):
         self.logger = logger or logging.getLogger(__name__)
         super(TransactionsInterface, self).__init__(endpoint=endpoint, endpoint_type='transactions', session_token=session_token,
-                                                    environment=environment, username=None, password=None)
+                                                    environment=environment, username=username, password=password)
 
     def new(self, transaction):
         self.logger.info('New Transaction - Asset Manager: %s - Transaction ID: %s', transaction.asset_manager_id,
@@ -33,7 +34,7 @@ class TransactionsInterface(Interface):
     def create_many(self, transactions):
         if type(transactions) is not list:
             raise ValueError('Error - create_many takes in a list of transactions instead of single transaction')
-        transactions_json = []        
+        transactions_json = []
         # check to ensure all transactions have the same asset_manager_id
         asset_manager_id = transactions[0].asset_manager_id
         for transaction in transactions:
@@ -228,8 +229,8 @@ class TransactionsInterface(Interface):
         parameters is a dictionary of all the mtm result filter parameters
         """
         self.logger.info('Retrieving mtm Positions - Asset Manager: %s', asset_manager_id)
-        url = '%s/mtm/%s' % (self.endpoint, asset_manager_id)       
-        paramaters.update({'book_id': book_id})  
+        url = '%s/mtm/%s' % (self.endpoint, asset_manager_id)
+        paramaters.update({'book_id': book_id})
         response = self.session.get(url, params = paramaters)
         if response.ok:
             mtm_results = [json_to_mtm_result(json_mtm_result) for json_mtm_result in response.json()]
@@ -251,7 +252,26 @@ class TransactionsInterface(Interface):
             return response.json()
         else:
             self.logger.error(response.text)
-            response.raise_for_status()    
+            response.raise_for_status()
+
+    def upsert_book_reports(self, asset_manager_id, book_reports, report_type):
+        self.logger.info('Insert book report for -Asset Manager: %s', asset_manager_id)
+        if not isinstance(book_reports, list):
+            book_reports = [book_reports]
+        book_report_json = []
+        for book_report in book_reports:
+            book_report_json.append(book_report.to_interface())
+        url = '%s/book-report/%s/%s' % (self.endpoint, asset_manager_id, report_type)
+        response = self.session.post(url, json=book_report_json, params={'upsert': True})
+        if response.ok:
+            book_reports = []
+            for book_report_json in response.json():
+                book_reports.append(json_to_book_report(book_report_json))
+            self.logger.info('Created %s Book Report', len(book_reports))
+            return book_reports
+        else:
+            self.logger.error(response.text)
+            response.raise_for_status()
 
     def new_transaction_pnls(self, asset_manager_id, transaction_pnls):
         self.logger.info('Insert Transaction PnL results for - Asset Manager: %s', asset_manager_id)
@@ -310,6 +330,28 @@ class TransactionsInterface(Interface):
             self.logger.error(response.text)
             response.raise_for_status()
 
+    def retrieve_book_reports(self, asset_manager_id, book_ids, report_type,
+                              report_date_start=None, report_date_end=None, period=None):
+        self.logger.info("""Retrieve Book %s Reports for - Asset Manager: %s""", \
+                            report_type, asset_manager_id)
+        url = '%s/book-report/%s/%s' % (self.endpoint, asset_manager_id, report_type)
+        params = {'book_ids': book_ids}
+        if period:
+            params['period'] = period
+        if report_date_start:
+            params['report_date_start'] = report_date_start
+        if report_date_end:
+            params['report_date_end'] = report_date_end
+
+        response = self.session.get(url, params=params)
+        if response.ok:
+            book_reports = [json_to_book_report(json_book_report) for json_book_report in response.json()]
+            self.logger.info('Returned %s Book Reports.', len(book_reports))
+            return book_reports
+        else:
+            self.logger.error(response.text)
+            response.raise_for_status()
+
     def retrieve_transaction_pnls(self, book_ids, asset_manager_id,
                                   business_date, periods=None,
                                   page_no=None, page_size=None):
@@ -333,7 +375,7 @@ class TransactionsInterface(Interface):
         else:
             self.logger.error(response.text)
             response.raise_for_status()
-    
+
     def new_position_pnls(self, asset_manager_id, position_pnls):
         self.logger.info('Insert Position PnL results for - Asset Manager: %s', asset_manager_id)
         if not isinstance(position_pnls, list):
@@ -351,7 +393,7 @@ class TransactionsInterface(Interface):
             return position_pnls
         else:
             self.logger.error(response.text)
-            response.raise_for_status() 
+            response.raise_for_status()
 
     def upsert_position_pnls(self, asset_manager_id, position_pnls):
         self.logger.info('Upsert Position PnL results for - Asset Manager: %s', asset_manager_id)
@@ -370,7 +412,7 @@ class TransactionsInterface(Interface):
             return position_pnls
         else:
             self.logger.error(response.text)
-            response.raise_for_status() 
+            response.raise_for_status()
 
     def amend_position_pnls(self, asset_manager_id, position_pnls):
         self.logger.info('Amend Position PnL results for - Asset Manager: %s', asset_manager_id)
@@ -429,11 +471,11 @@ class TransactionsInterface(Interface):
             return transactions
         else:
             self.logger.error(response.text)
-            response.raise_for_status()        
+            response.raise_for_status()
 
     def position_search(self, asset_manager_id, book_ids=None, account_ids=None,
                         accounting_types=None, asset_ids=None,
-                        position_date=None, include_cash=False, 
+                        position_date=None, include_cash=False,
                         page_no=None, page_size=None):
         self.logger.info('Search Positions - Asset Manager: %s', asset_manager_id)
         search_params = {}
@@ -626,4 +668,4 @@ class TransactionsInterface(Interface):
             return response.json()
         else:
             self.logger.error(response.text)
-            response.raise_for_status()
\ No newline at end of file
+            response.raise_for_status()
