@@ -8,6 +8,7 @@ from amaascore.transactions.transaction import Transaction
 from amaascore.transactions.mtm_result import MTMResult
 from amaascore.transactions.transaction_pnl import TransactionPNL
 from amaascore.transactions.position_pnl import PositionPNL
+from amaascore.transactions.book_report import BookReport
 
 def json_to_position(json_position):
     position = Position(**json_position)
@@ -74,4 +75,16 @@ def json_to_position_pnl(position_pnl_json):
         return PositionPNL(**position_pnl_json)
     else:
         raise ValueError("Missing Fields: %s in class: PositionPNL" %
+                         ",".join(missing))
+
+
+def json_to_book_report(book_report_json):
+    args = inspect.getfullargspec(BookReport.__init__)
+    mandatory = set(args.args[1:len(args.args) - len(args.defaults)])
+    missing = mandatory - \
+        set([attr for attr in mandatory if book_report_json.get(attr) is not None])
+    if not missing:
+        return BookReport(**book_report_json)
+    else:
+        raise ValueError("Missing Fields: %s in class: BookReport" %
                          ",".join(missing))
\ No newline at end of file
